/*!
* Do not modify this file directly.  It is compiled Sass code.
* @see: jetpack/_inc/jetpack.scss
*/
.jp-jitm {
  border-radius: 2px;
  max-width: 95%;
  margin: 2em auto 0 auto;
  padding: .85em;
  background: #fcfcfc;
  border: 1px solid #dedede;
  text-align: center;
}
@media (min-width: 1100px) {
  .jp-jitm {
    max-width: 650px;
  }
}
.jp-jitm:before, .jp-jitm:after {
  content: "";
  display: table;
}
.jp-jitm:after {
  clear: both;
}
.jp-jitm .activate {
  margin-top: .8em;
}
.jp-jitm .jp-emblem {
  width: 25px;
  height: 25px;
  margin: .45em auto .65em auto;
}
.jp-jitm svg {
  width: 100%;
  height: 100%;
}
.jp-jitm path {
  fill: #8cc258;
}
.jp-jitm .dismiss {
  margin: 0;
  text-decoration: none;
  float: left;
}
.jp-jitm .dismiss:before {
  color: #666;
  font: 400 15px/1 dashicons;
  content: '\f158';
}
.jp-jitm p {
  font-size: 1em;
  line-height: 165%;
}

.media-upload-form .jp-jitm {
  max-width: 100%;
}
@media (min-width: 1100px) {
  .media-upload-form .jp-jitm .jp-emblem, .media-upload-form .jp-jitm p {
    float: right;
    margin: 0 0 0 1em;
    padding-top: 4px;
  }
  .media-upload-form .jp-jitm .jp-emblem {
    width: 20px;
    height: 20px;
  }
  .media-upload-form .jp-jitm p + p {
    margin: 0;
    padding: 0;
  }
  .media-upload-form .jp-jitm .activate {
    margin-top: 0;
  }
}

@media (max-width: 1100px) {
  .media-modal-content .jp-jitm {
    max-width: 90%;
  }
}

.jetpack-connected .media-modal-content .uploader-inline-content {
  top: 20%;
}

/*# sourceMappingURL=jetpack-admin-jitm.css.map */
.jp-jitm{border-radius:2px;max-width:95%;margin:2em auto 0 auto;padding:.85em;background:#fcfcfc;border:1px solid #dedede;text-align:center}@media (min-width: 1100px){.jp-jitm{max-width:650px}}.jp-jitm:before,.jp-jitm:after{content:"";display:table}.jp-jitm:after{clear:both}.jp-jitm .activate{margin-top:.8em}.jp-jitm .jp-emblem{width:25px;height:25px;margin:.45em auto .65em auto}.jp-jitm svg{width:100%;height:100%}.jp-jitm path{fill:#8cc258}.jp-jitm .dismiss{margin:0;text-decoration:none;float:left}.jp-jitm .dismiss:before{color:#666;font:400 15px/1 dashicons;content:'\f158'}.jp-jitm p{font-size:1em;line-height:165%}.media-upload-form .jp-jitm{max-width:100%}@media (min-width: 1100px){.media-upload-form .jp-jitm .jp-emblem,.media-upload-form .jp-jitm p{float:right;margin:0 0 0 1em;padding-top:4px}.media-upload-form .jp-jitm .jp-emblem{width:20px;height:20px}.media-upload-form .jp-jitm p+p{margin:0;padding:0}.media-upload-form .jp-jitm .activate{margin-top:0}}@media (max-width: 1100px){.media-modal-content .jp-jitm{max-width:90%}}.jetpack-connected .media-modal-content .uploader-inline-content{top:20%}

/*# sourceMappingURL=jetpack-admin-jitm.min.css.map */