module.exports = {
	'h3': {
		fontWeight: 'normal'
	},

	'content': {
		fontSize: 'larger',
		color: '#777',
		lineHeight: 1.5,
  		margin: '1em 0'
	},

	'screenshot': {
		float: 'right',
		width: 300,
		border: '1px solid #ccc'
	},

	css: {
		h4: {
			marginBottom: 10,
		},

		h5: {
			marginTop: 0,
			fontSize: '1em',
			fontWeight: 400
		},

		'input, select': {
			margin: 1,
			padding: '3px 5px'
		},

		'input[type="text"]': {
			width: '100%'
		},

		'.submit': {
			margin: '0px !important',
			padding: '5px 5px !important',
			backgroundColor: '#EEE',
			textAlign: 'right'
		}
	}
};