#accordion-section-menu_locations {
	position: relative;
	margin-bottom: 15px;
}

.menu-in-location,
.menu-in-locations {
	display: block;
	font-weight: 600;
	font-size: 10px;
}

#customize-controls .theme-location-set,
#customize-controls .control-section .accordion-section-title:focus .menu-in-location,
#customize-controls .control-section .accordion-section-title:hover .menu-in-location,
#customize-controls .control-section .accordion-section-title:focus .menu-in-locations,
#customize-controls .control-section .accordion-section-title:hover .menu-in-locations {
	color: #555;
}

.wp-customizer .menu-item-bar .menu-item-handle,
.wp-customizer .menu-item-settings,
.wp-customizer .menu-item-settings .description-thin {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

.wp-customizer .menu-item-bar {
	margin: 0;
}

.wp-customizer .menu-item-bar .menu-item-handle {
	width: 100%;
	background: #fff;
}

.wp-customizer .menu-item-handle .item-title {
	margin-left: 0;
}

.wp-customizer .menu-item-handle .item-type {
	padding: 1px 5px 0 21px;
	float: left;
	text-align: left;
}

.wp-customizer .menu-item-settings {
	max-width: 100%;
	overflow: hidden;
	padding: 10px;
	background: #eee;
	border: 1px solid #999;
	border-top: none;
}

.wp-customizer .menu-item-settings .description-thin {
	width: 100%;
	height: auto;
	margin: 0 0 8px 0;
}

.wp-customizer .menu-item-settings input[type="text"] {
	width: 100%;
}

.wp-customizer .menu-item-settings .submitbox {
	margin: 0;
	padding: 0;
}

.wp-customizer .menu-item-settings .link-to-original {
	padding: 5px 0;
	border: none;
	font-style: normal;
	margin: 0;
	width: 100%;
}

.wp-customizer .menu-item .submitbox .submitdelete {
	display: block;
	float: right;
	margin: 6px 0 0;
	padding: 0;
	cursor: pointer;
}

.wp-customizer .menu-item .submitbox .submitdelete:focus {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

/* Menu-item reordering nav. */
.customize-control-nav_menu .reordering .reorder,
.customize-control-nav_menu .reorder-done {
	display: none;
}

.customize-control-nav_menu .reorder,
.customize-control-nav_menu .reordering .reorder-done {
	display: inline-block;
	padding: 5px 8px;
}

.menu-item-reorder-nav {
	display: none;
	background-color: #fff;
	position: absolute;
	top: 0;
	left: 0;
}

.customize-control-nav_menu .reordering .add-new-menu-item {
	opacity: 0.2;
	pointer-events: none;
	cursor: not-allowed;
}

.menu-item-reorder-nav button {
	position: relative;
	overflow: hidden;
	float: right;
	display: block;
	width: 30px;
	height: 40px;
	color: #82878c;
	text-indent: -9999px;
	cursor: pointer;
	background: transparent;
	border: none;
	-webkit-box-shadow: none;
	box-shadow: none;
	outline: none;
}

.menu-item-reorder-nav button:before {
	display: inline-block;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	font: normal 20px/40px dashicons;
	text-align: center;
	text-indent: 0;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.menu-item-reorder-nav button:hover,
.menu-item-reorder-nav button:focus {
	color: #191e23;
	background: #eee;
}

.menus-move-down:before {
	content: '\f347';
}

.menus-move-up:before {
	content: '\f343';
}

.menus-move-left:before {
	content: '\f341';
}

.menus-move-right:before {
	content: '\f345';
}

.move-up-disabled .menus-move-up,
.move-down-disabled .menus-move-down,
.move-right-disabled .menus-move-right,
.move-left-disabled .menus-move-left {
	color: #d5d5d5 !important;
	background-color: #fff !important;
	cursor: default;
	pointer-events: none;
}

.menu-item-reorder-nav:before {
	content: "";
	display: block;
	position: absolute;
	right: -10px;
	width: 10px;
	height: 40px;
	background: -webkit-linear-gradient(right, rgba(250,250,250,0) 0%,rgba(250,250,250,1) 100%);
	background: -webkit-gradient(linear, right top, left top, from(rgba(250,250,250,0)), to(rgba(250,250,250,1)));
	background: -webkit-linear-gradient(right, rgba(250,250,250,0) 0%, rgba(250,250,250,1) 100%);
	background: linear-gradient(to left, rgba(250,250,250,0) 0%,rgba(250,250,250,1) 100%);
}

.reordering .menu-item .item-controls,
.reordering .menu-item .item-type {
	display: none;
}

.reordering .menu-item-reorder-nav {
	display: block;
}

.customize-control input.menu-name-field {
	width: 100%; /* Override the 98% default for customizer inputs, to align with the size of menu items. */
	margin: 12px 0;
}

.wp-customizer .menu-item .item-edit {
	position: absolute;
	left: -19px;
	top: 2px;
	display: block;
	width: 30px;
	height: 38px;
	margin-left: 0 !important;
	outline: none;
	overflow: hidden;
	cursor: pointer;
}

.customize-control-nav_menu_item .item-edit:focus {
	color: #0073aa;
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

/* rework the arrow indicator implementation for NVDA bug same as #32715 */
.wp-customizer .menu-item .item-edit .toggle-indicator {
	display: inline-block;
	font-size: 20px;
	line-height: 1;
}

.wp-customizer .menu-item .item-edit .toggle-indicator:after {
	content: '\f140';
	font: normal 20px/1 dashicons;
	color: #a0a5aa;
	vertical-align: top;
	speak: none;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	text-decoration: none !important;
}

.wp-customizer .menu-item.menu-item-edit-active .item-edit .toggle-indicator:after {
	content: '\f142';
}

.wp-customizer .menu-item-settings p.description {
	font-style: normal;
}

.wp-customizer .menu-settings dl {
	margin: 12px 0 0 0;
	padding: 0;
}

.wp-customizer .menu-settings .checkbox-input {
	margin-top: 8px;
}

.wp-customizer .menu-settings .menu-theme-locations {
	border-top: 1px solid #ccc;
}

.wp-customizer .menu-settings {
	margin-top: 36px;
	border-top: none;
}

.menu-settings .customize-control-checkbox label {
	line-height: 1;
}

/* @todo update selector or potentially remove */
.menu-settings .customize-control.customize-control-checkbox {
	margin-bottom: 8px; /* Override collapsing at smaller viewports. */
}

.customize-control-menu {
	margin-top: 4px;
}

#customize-controls .customize-info.open.active-menu-screen-options .customize-help-toggle {
	color: #555;
}

/* Screen Options */
.customize-screen-options-toggle {
	background: none;
	border: none;
	color: #555;
	cursor: pointer;
	margin: 0;
	padding: 20px;
	position: absolute;
	left: 0;
	top: 30px;
}

#customize-controls .customize-info .customize-help-toggle {
	padding: 20px;
}

#customize-controls .customize-info .customize-help-toggle:before {
	padding: 4px;
}

.customize-screen-options-toggle:hover,
.customize-screen-options-toggle:active,
.customize-screen-options-toggle:focus,
.active-menu-screen-options .customize-screen-options-toggle,
#customize-controls .customize-info.open.active-menu-screen-options .customize-help-toggle:hover,
#customize-controls .customize-info.open.active-menu-screen-options .customize-help-toggle:active,
#customize-controls .customize-info.open.active-menu-screen-options .customize-help-toggle:focus {
	color: #0073aa;
}

.customize-screen-options-toggle:focus,
#customize-controls .customize-info .customize-help-toggle:focus {
	outline: none;
}

.customize-screen-options-toggle:before {
	-moz-osx-font-smoothing: grayscale;
	border: none;
	content: "\f111";
	display: block;
	font: 18px/1 "dashicons";
	padding: 5px;
	text-align: center;
	text-decoration: none !important;
	text-indent: 0;
	right: 6px;
	position: absolute;
	top: 6px;
}

.customize-screen-options-toggle:focus:before,
#customize-controls .customize-info .customize-help-toggle:focus:before {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	-webkit-border-radius: 100%;
	border-radius: 100%;
}

.wp-customizer #screen-options-wrap {
	display: none;
	background: #fff;
	border-top: 1px solid #ddd;
	padding: 4px 15px 0;
}

.wp-customizer .metabox-prefs label {
	display: block;
	padding-left: 0;
	line-height: 30px;
}

#accordion-panel-nav_menus .field-link-target,
#accordion-panel-nav_menus .field-attr-title,
#accordion-panel-nav_menus .field-css-classes,
#accordion-panel-nav_menus .field-xfn,
#accordion-panel-nav_menus .field-description {
	display: none;
}

#accordion-panel-nav_menus.field-link-target-active .field-link-target,
#accordion-panel-nav_menus.field-attr-title-active .field-attr-title,
#accordion-panel-nav_menus.field-css-classes-active .field-css-classes,
#accordion-panel-nav_menus.field-xfn-active .field-xfn,
#accordion-panel-nav_menus.field-description-active .field-description {
	display: block;
}

/* WARNING: The 20px factor is hard-coded in JS. */
.menu-item-depth-0  { margin-right: 0;     }
.menu-item-depth-1  { margin-right: 20px;  }
.menu-item-depth-2  { margin-right: 40px;  }
.menu-item-depth-3  { margin-right: 60px;  }
.menu-item-depth-4  { margin-right: 80px;  }
.menu-item-depth-5  { margin-right: 100px; }
.menu-item-depth-6  { margin-right: 120px; }
.menu-item-depth-7  { margin-right: 140px; }
.menu-item-depth-8  { margin-right: 160px; } /* Not likely to be used or useful beyond this depth */
.menu-item-depth-9  { margin-right: 180px; }
.menu-item-depth-10 { margin-right: 200px; }
.menu-item-depth-11 { margin-right: 220px; }

/* @todo handle .menu-item-settings width */
.menu-item-depth-0  > .menu-item-bar { margin-left: 0;     }
.menu-item-depth-1  > .menu-item-bar { margin-left: 20px;  }
.menu-item-depth-2  > .menu-item-bar { margin-left: 40px;  }
.menu-item-depth-3  > .menu-item-bar { margin-left: 60px;  }
.menu-item-depth-4  > .menu-item-bar { margin-left: 80px;  }
.menu-item-depth-5  > .menu-item-bar { margin-left: 100px; }
.menu-item-depth-6  > .menu-item-bar { margin-left: 120px; }
.menu-item-depth-7  > .menu-item-bar { margin-left: 140px; }
.menu-item-depth-8  > .menu-item-bar { margin-left: 160px; }
.menu-item-depth-9  > .menu-item-bar { margin-left: 180px; }
.menu-item-depth-10 > .menu-item-bar { margin-left: 200px; }
.menu-item-depth-11 > .menu-item-bar { margin-left: 220px; }

/* Submenu left margin. */
.menu-item-depth-0  .menu-item-transport { margin-right: 0;      }
.menu-item-depth-1  .menu-item-transport { margin-right: -20px;  }
.menu-item-depth-3  .menu-item-transport { margin-right: -60px;  }
.menu-item-depth-4  .menu-item-transport { margin-right: -80px;  }
.menu-item-depth-2  .menu-item-transport { margin-right: -40px;  }
.menu-item-depth-5  .menu-item-transport { margin-right: -100px; }
.menu-item-depth-6  .menu-item-transport { margin-right: -120px; }
.menu-item-depth-7  .menu-item-transport { margin-right: -140px; }
.menu-item-depth-8  .menu-item-transport { margin-right: -160px; }
.menu-item-depth-9  .menu-item-transport { margin-right: -180px; }
.menu-item-depth-10 .menu-item-transport { margin-right: -200px; }
.menu-item-depth-11 .menu-item-transport { margin-right: -220px; }

/* WARNING: The 20px factor is hard-coded in JS. */
.reordering .menu-item-depth-0  { margin-right: 0;     }
.reordering .menu-item-depth-1  { margin-right: 15px;  }
.reordering .menu-item-depth-2  { margin-right: 30px;  }
.reordering .menu-item-depth-3  { margin-right: 45px;  }
.reordering .menu-item-depth-4  { margin-right: 60px;  }
.reordering .menu-item-depth-5  { margin-right: 75px;  }
.reordering .menu-item-depth-6  { margin-right: 90px;  }
.reordering .menu-item-depth-7  { margin-right: 105px; }
.reordering .menu-item-depth-8  { margin-right: 120px; } /* Not likely to be used or useful beyond this depth */
.reordering .menu-item-depth-9  { margin-right: 135px; }
.reordering .menu-item-depth-10 { margin-right: 150px; }
.reordering .menu-item-depth-11 { margin-right: 165px; }

.reordering .menu-item-depth-0  > .menu-item-bar { margin-left: 0;     }
.reordering .menu-item-depth-1  > .menu-item-bar { margin-left: 15px;  }
.reordering .menu-item-depth-2  > .menu-item-bar { margin-left: 30px;  }
.reordering .menu-item-depth-3  > .menu-item-bar { margin-left: 45px;  }
.reordering .menu-item-depth-4  > .menu-item-bar { margin-left: 60px;  }
.reordering .menu-item-depth-5  > .menu-item-bar { margin-left: 75px;  }
.reordering .menu-item-depth-6  > .menu-item-bar { margin-left: 90px;  }
.reordering .menu-item-depth-7  > .menu-item-bar { margin-left: 105px; }
.reordering .menu-item-depth-8  > .menu-item-bar { margin-left: 120px; }
.reordering .menu-item-depth-9  > .menu-item-bar { margin-left: 135px; }
.reordering .menu-item-depth-10 > .menu-item-bar { margin-left: 150px; }
.reordering .menu-item-depth-11 > .menu-item-bar { margin-left: 165px; }

.control-section-nav_menu .menu .menu-item-edit-active {
	margin-right: 0;
}

.control-section-nav_menu .menu .menu-item-edit-active .menu-item-bar {
	margin-left: 0;
}

.control-section-nav_menu .menu .sortable-placeholder {
	margin-top: 0;
	margin-bottom: 1px;
	max-width: -webkit-calc(100% - 2px);
	max-width: calc(100% - 2px);
	float: right;
	display: list-item;
	border-color: #a0a5aa;
}

.menu-item-transport li.customize-control {
	float: none;
}

.control-section-nav_menu .menu ul.menu-item-transport .menu-item-bar {
	margin-top: 0;
}

/*
 * Add-menu-items mode.
 */
.wp-full-overlay-main {
	left: auto; /* This overrides a right: 0; which causes the preview to resize rather than slide off screen at the normal size. */
	width: 100%;
}

.adding-menu-items .control-section {
	opacity: .4;
}

.adding-menu-items .control-panel.control-section,
.adding-menu-items .control-section.open {
	opacity: 1;
}

/* Add-new button. */
#customize-theme-controls .add-new-menu-item {
	cursor: pointer;
	float: left;
	margin-right: 10px;
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	outline: none;
}

.add-new-menu-item:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	right: -2px;
	top: -1px;
	font: normal 20px/1 'dashicons';
	vertical-align: middle;
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.adding-menu-items .add-new-menu-item,
.adding-menu-items .add-new-menu-item:hover,
.add-menu-toggle.open,
.add-menu-toggle.open:hover {
	background: #eee;
	border-color: #929793;
	color: #32373c;
	-webkit-box-shadow: inset 0 2px 5px -3px rgba(0, 0, 0, 0.5);
	box-shadow: inset 0 2px 5px -3px rgba(0, 0, 0, 0.5);
}

.adding-menu-items .add-new-menu-item:before,
#accordion-section-add_menu .add-new-menu-item.open:before {
	-webkit-transform: rotate(-45deg);
	-ms-transform: rotate(-45deg);
	transform: rotate(-45deg);
}

.menu-item-bar .item-delete {
	color: #a00;
	position: absolute;
	top: 2px;
	left: -19px;
	width: 30px;
	height: 38px;
	cursor: pointer;
	display: none;
}

.menu-item-bar .item-delete:before {
	content: "\f335";
	font: normal 20px/1 dashicons;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	position: absolute;
	top: 9px;
	right: 5px;
}

.ie8 .menu-item-bar .item-delete:before {
	top: -10px;
}

.menu-item-bar .item-delete:hover,
.menu-item-bar .item-delete:focus {
	color: #f00;
}

.menu-item-bar .item-delete:focus {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

.adding-menu-items .menu-item-bar .item-edit {
	display: none;
}

.adding-menu-items .menu-item-bar .item-delete {
	display: block;
}

#available-menu-items .item {
	position: static;
}

#available-menu-items {
	position: absolute;
	top: 0;
	bottom: 0;
	right: -301px;
	visibility: hidden;
	overflow-x: hidden;
	overflow-y: auto;
	width: 300px;
	margin: 0;
	z-index: 4;
	background: #eee;
	-webkit-transition: right .18s;
	transition: right .18s;
	border-left: 1px solid #ddd;
}

#available-menu-items.opening {
	overflow-y: hidden; /* avoid scrollbar jitter with animating heights */
}

#available-menu-items #available-menu-items-search.open {
	height: 100%;
	border-bottom: none;
}

#available-menu-items .accordion-section-title {
	border-right: none;
	border-left: none;
	background: #fff;
}

#available-menu-items .open .accordion-section-title,
#available-menu-items #available-menu-items-search .accordion-section-title {
	background: #eee;
}

/* rework the arrow indicator implementation for NVDA bug see #32715 */
#available-menu-items .accordion-section-title:after {
	content: none !important;
}

#available-menu-items .accordion-section-title .toggle-indicator {
	display: inline-block;
	font-size: 20px;
	line-height: 1;
}

#available-menu-items .accordion-section-title .toggle-indicator:after {
	content: '\f140';
	font: normal 20px/1 'dashicons';
	color: #a0a5aa;
	vertical-align: top;
	speak: none;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	text-decoration: none !important;
}

#available-menu-items .accordion-section-title:hover .toggle-indicator:after {
	color: #777;
}

#available-menu-items .open .accordion-section-title .toggle-indicator:after {
	content: '\f142';
}

#available-menu-items .accordion-section-content {
	overflow-y: auto;
	max-height: 200px; /* This gets set in JS to fit the screen size, and based on # of sections. */
	background: transparent;
}

button.not-a-button {
	background: transparent;
	border: none;
	-webkit-box-shadow: none;
	box-shadow: none;
	-webkit-border-radius: 0;
	border-radius: 0;
	outline: 0;
	padding: 0;
	margin: 0;
}

#available-menu-items .accordion-section-title button {
	display: block;
	width: 28px;
	height: 35px;
	position: absolute;
	top: 5px;
	left: 5px;
	cursor: pointer;
}

#available-menu-items .accordion-section-title button:focus {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

#available-menu-items .accordion-section-title .no-items,
#available-menu-items .cannot-expand .accordion-section-title .spinner,
#available-menu-items .cannot-expand .accordion-section-title > button {
	display: none;
}

#available-menu-items-search.cannot-expand .accordion-section-title .spinner {
	display: block;
}

#available-menu-items .cannot-expand .accordion-section-title .no-items {
	display: block;
	color: #777;
	font-weight: normal;
	float: left;
	margin-right: 5px;
}

#available-menu-items .accordion-section-content {
	padding: 1px 15px 15px 15px;
	margin: 0;
	min-height: 120px;
	max-height: 290px;
}

#available-menu-items #available-menu-items-search .accordion-section-content {
	position: absolute;
	right: 1px;
	top: 60px; /* below title div / search input */
	bottom: 0px; /* 100% height that still triggers lazy load */
	max-height: none;
	width: 100%;
	padding: 1px 15px 15px;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

#available-menu-items .menu-item-tpl {
	margin: 0;
}

#custom-menu-item-name.invalid,
#custom-menu-item-url.invalid,
.menu-name-field.invalid,
.menu-name-field.invalid:focus {
	border: 1px solid #f00;
}

#available-menu-items .item-tpl {
	position: relative;
	padding: 20px 60px 20px 15px;
	border-bottom: 1px solid #e4e4e4;
	cursor: pointer;
	display: none;
}

#available-menu-items .item-tpl:hover,
#available-menu-items .item-tpl.selected {
	background: #eee;
}

#available-menu-items .menu-item-handle .item-type {
	padding-left: 0;
}

#available-menu-items .menu-item-handle .item-title {
	padding-right: 20px;
}

#available-menu-items .menu-item-handle {
	cursor: pointer;
}

#available-menu-items .item-top,
#available-menu-items .item-top:hover {
	border: none;
	background: transparent;
	-webkit-box-shadow: none;
	box-shadow: none;
}

#available-menu-items .menu-item-handle {
	-webkit-box-shadow: none;
	box-shadow: none;
	margin-top: -1px;
}

#available-menu-items .menu-item-handle:hover {
	z-index: 1;
}

#available-menu-items .item-title h4 {
	padding: 0 0 5px;
	font-size: 14px;
}

#available-menu-items .item-add {
	position: absolute;
	top: 1px;
	right: 1px;
	color: #82878c;
	width: 30px;
	height: 38px;
	cursor: pointer;
}

#available-menu-items .menu-item-handle .item-add:focus {
	color: #23282d;
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

#available-menu-items .item-add:before {
	content: "\f543";
	font: normal 20px/1 dashicons;
	position: relative;
	right: 2px;
	top: 3px;
}

#available-menu-items .menu-item-handle.item-added .item-type,
#available-menu-items .menu-item-handle.item-added .item-title,
#available-menu-items .menu-item-handle.item-added:hover .item-add,
#available-menu-items .menu-item-handle.item-added .item-add:focus {
	color: #82878c;
}

#available-menu-items .menu-item-handle.item-added .item-add:before {
	content: "\f147";
}

#available-menu-items .accordion-section-title.loading .spinner,
#available-menu-items-search.loading .accordion-section-title .spinner {
	visibility: visible;
	margin: 0 20px;
}

#available-menu-items-search .clear-results {
	position: absolute;
	top: 20px;
	left: 20px;
	width: 20px;
	height: 20px;
	cursor: pointer;
	color: #a00;
	text-decoration: none;
}

#available-menu-items-search .clear-results,
#available-menu-items-search.loading .clear-results.is-visible {
	display: none;
}

#available-menu-items-search .clear-results.is-visible {
	display: block;
}

#available-menu-items-search .clear-results:before {
	content: "\f335";
	font: normal 20px/1 dashicons;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

#available-menu-items-search .clear-results:hover,
#available-menu-items-search .clear-results:focus {
	color: #f00;
}

#available-menu-items-search .clear-results:focus {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

#available-menu-items-search .spinner {
	position: absolute;
	top: 20px;
	margin: 0 !important;
	left: 20px;
}

#available-menu-items-search input {
	padding: 6px 10px;
	width: 100%;
}

#available-menu-items-search .accordion-section-title {
	padding: 12px 15px;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

#available-menu-items-search .accordion-section-title:after {
	display: none;
}

#available-menu-items-search .accordion-section-content:empty {
	min-height: 0;
	padding: 0;
}

#available-menu-items-search.loading .accordion-section-content div {
	opacity: .5;
}

#available-menu-items-search.loading.loading-more .accordion-section-content div {
	opacity: 1;
}

#customize-preview {
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
}

body.adding-menu-items #available-menu-items {
	right: 0;
	visibility: visible;
}

body.adding-menu-items .wp-full-overlay-main {
	right: 300px;
}

body.adding-menu-items #customize-preview {
	opacity: 0.4;
}

.menu-item-handle .spinner {
	display: none;
	float: right;
	margin: 0 0 0 8px;
}

.nav-menu-inserted-item-loading .spinner {
	display: block;
}

.nav-menu-inserted-item-loading .menu-item-handle .item-type {
	padding: 0 8px 0 0;
}

.nav-menu-inserted-item-loading .menu-item-handle,
.added-menu-item .menu-item-handle.loading {
	padding: 10px 8px 10px 15px;
	cursor: default;
	opacity: .5;
	background: #fff;
	color: #727773;
}

.added-menu-item .menu-item-handle {
	-webkit-transition-property: opacity, background, color;
	transition-property: opacity, background, color;
	-webkit-transition-duration: 1.25s;
	transition-duration: 1.25s;
	-webkit-transition-timing-function: cubic-bezier( .25, -2.5, .75, 8 );
	transition-timing-function: cubic-bezier( .25, -2.5, .75, 8 ); /* Replacement for .hide().fadeIn('slow') in JS to add emphasis when it's loaded. */
}

/* Add/delete Menus */

/* @todo update selector */
#accordion-section-add_menu {
	margin: 15px 12px;
}

.new-menu-section-content {
	display: none;
	padding: 15px 0 0 0;
	clear: both;
}

/* @todo update selector */
#accordion-section-add_menu .accordion-section-title {
	padding-right: 45px;
}

/* @todo update selector */
#accordion-section-add_menu .accordion-section-title:before {
	font: normal 20px/1 dashicons;
	position: absolute;
	top: 12px;
	right: 14px;
	content: "\f132";
}

#create-new-menu-submit {
	float: left;
	margin: 0 0 12px 0;
}

.menu-delete-item {
	display: block;
	float: right;
	padding: 1em 0;
	width: 100%;
}

li.assigned-to-menu-location .menu-delete-item {
  display: none;
}

li.assigned-to-menu-location .add-new-menu-item {
  margin-bottom: 1em;
}

.menu-delete {
	color: #a00;
	cursor: pointer;
	text-decoration: underline;
}

.menu-delete:hover,
.menu-delete:focus {
	color: #f00;
	text-decoration: none;
}

.menu-delete:focus {
	-webkit-box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
	box-shadow: 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, .8);
}

.menu-item-handle {
	margin-top: -1px;
}
.ui-sortable-disabled .menu-item-handle {
	cursor: default;
}

.menu-item-handle:hover {
	position: relative;
	z-index: 10;
	color: #0073aa;
}

.menu-item-handle:hover .item-type,
.menu-item-handle:hover .item-edit,
#available-menu-items .menu-item-handle:hover .item-add {
	color: #0073aa;
}

.menu-item-edit-active .menu-item-handle {
	border-color: #999;
	border-bottom: none;
}

.customize-control-nav_menu_item {
	margin-bottom: 0;
}

.customize-control-nav_menu {
	margin-top: 12px;
}

#available-menu-items .customize-section-title {
	display: none;
}

@media screen and ( max-width: 782px ) {
	#available-menu-items #available-menu-items-search .accordion-section-content {
		top: 63px;
	}
}

@media screen and ( max-width: 640px ) {
	body.adding-menu-items div#available-menu-items {
		top: 46px;
		right: 0;
		z-index: 10;
		width: 100%;
	}

	#available-menu-items #available-menu-items-search .accordion-section-content {
		top: 133px;
	}

	#available-menu-items .customize-section-title {
		display: block;
		margin: 0;
	}

	#available-menu-items .customize-section-back {
		height: 69px;
	}

	#available-menu-items .customize-section-title h3 {
		font-size: 20px;
		font-weight: 200;
		padding: 9px 14px 12px 10px;
		margin: 0;
		line-height: 24px;
		color: #555;
		display: block;
		overflow: hidden;
		white-space: nowrap;
		text-overflow: ellipsis;
	}

	#available-menu-items .customize-section-title .customize-action {
		font-size: 13px;
		display: block;
		font-weight: 400;
		overflow: hidden;
		white-space: nowrap;
		text-overflow: ellipsis;
	}
}
