button{background:transparent;border:none;padding:0;vertical-align:baseline}._3KHDMvFXbIlUHCr6xNAUgc,button{outline:0;font-size:14px;-webkit-appearance:none;-moz-appearance:none;appearance:none}._3KHDMvFXbIlUHCr6xNAUgc{background:#f3f6f8;border-color:#c8d7e1;border-style:solid;border-width:1px 1px 2px;color:#2e4453;cursor:pointer;display:inline-block;margin:0;overflow:hidden;font-weight:600;text-overflow:ellipsis;text-decoration:none;vertical-align:top;box-sizing:border-box;line-height:21px;border-radius:4px;padding:7px 14px 9px}._3KHDMvFXbIlUHCr6xNAUgc:hover{border-color:#a8bece;color:#2e4453}._3KHDMvFXbIlUHCr6xNAUgc:active{border-width:2px 1px 1px}._3KHDMvFXbIlUHCr6xNAUgc:visited{color:#2e4453}._3KHDMvFXbIlUHCr6xNAUgc:disabled,._3KHDMvFXbIlUHCr6xNAUgc[disabled]{color:#e9eff3;background:#fff;border-color:#e9eff3;cursor:default}._3KHDMvFXbIlUHCr6xNAUgc:disabled:active,._3KHDMvFXbIlUHCr6xNAUgc[disabled]:active{border-width:1px 1px 2px}._3KHDMvFXbIlUHCr6xNAUgc:focus{border-color:#00aadc;box-shadow:0 0 0 2px #78dcfa}._3KHDMvFXbIlUHCr6xNAUgc.j0hwiL3tY0QkUXHQUkSM7{border-color:#c8d7e1;border-style:solid;border-width:1px 1px 2px;color:#2e4453;background:#57972d;border-color:#518d2a;color:#fff}._3KHDMvFXbIlUHCr6xNAUgc.j0hwiL3tY0QkUXHQUkSM7:hover{border-color:#2b4b16;color:#fff}._3KHDMvFXbIlUHCr6xNAUgc.j0hwiL3tY0QkUXHQUkSM7:focus{border-color:#2b4b16}._3KHDMvFXbIlUHCr6xNAUgc.j0hwiL3tY0QkUXHQUkSM7[disabled]{background:tint(#57972d,50%);border-color:tint(#518d2a,55%);color:#fff}._3KHDMvFXbIlUHCr6xNAUgc.hK64lec226SvbxPVVinlu{background:transparent;border:none;border-radius:0;padding:0;color:#00aadc;font-weight:400;font-size:inherit;line-height:1.65}._3KHDMvFXbIlUHCr6xNAUgc.hK64lec226SvbxPVVinlu:active,._3KHDMvFXbIlUHCr6xNAUgc.hK64lec226SvbxPVVinlu:focus,._3KHDMvFXbIlUHCr6xNAUgc.hK64lec226SvbxPVVinlu:hover{color:tint(#00aadc,20%);box-shadow:none}._3KHDMvFXbIlUHCr6xNAUgc._2cNBg3RpMU_13Mcsg31Nii{display:none}._3KHDMvFXbIlUHCr6xNAUgc._2ZeZ_McW8Nyi3Ope7kh8n6{line-height:inherit}._3KHDMvFXbIlUHCr6xNAUgc._2ZeZ_McW8Nyi3Ope7kh8n6:before{display:inline-block;vertical-align:middle;margin-top:-2px;font-size:16px;font-style:normal;font-weight:400}._3KHDMvFXbIlUHCr6xNAUgc._1ZeevspAauN3fE8d08qfh_,._3KHDMvFXbIlUHCr6xNAUgc.CKVZIwvCYrB7Og65aZK2W{background:#00aadc;border-color:#0087be;color:#fff}._3KHDMvFXbIlUHCr6xNAUgc._1ZeevspAauN3fE8d08qfh_:hover,._3KHDMvFXbIlUHCr6xNAUgc.CKVZIwvCYrB7Og65aZK2W:hover{border-color:#005082;color:#fff}._3KHDMvFXbIlUHCr6xNAUgc._1ZeevspAauN3fE8d08qfh_:focus,._3KHDMvFXbIlUHCr6xNAUgc.CKVZIwvCYrB7Og65aZK2W:focus{border-color:#005082}._3KHDMvFXbIlUHCr6xNAUgc._1ZeevspAauN3fE8d08qfh_[disabled],._3KHDMvFXbIlUHCr6xNAUgc.CKVZIwvCYrB7Og65aZK2W[disabled]{background:tint(#78dcfa,50%);border-color:tint(#0087be,55%);color:#fff}._3KHDMvFXbIlUHCr6xNAUgc._2BK_mU5b50QTOMmctRgr8Y{color:#d94f4f}._3KHDMvFXbIlUHCr6xNAUgc._2BK_mU5b50QTOMmctRgr8Y[disabled]{color:#f4cdcd}._3KHDMvFXbIlUHCr6xNAUgc._2P1BZEzpOVni1B1KVPctfn{background:#d94f4f;border-color:#a02222;color:#fff}._3KHDMvFXbIlUHCr6xNAUgc._2P1BZEzpOVni1B1KVPctfn[disabled]{background:#eba3a3;border-color:tint(#d94f4f,30%)}._1Hib1kNYIh4Y88GJR20ixL.qQj_Fo0Xr3ekPOCy_oQX0 ._3KHDMvFXbIlUHCr6xNAUgc,._3KHDMvFXbIlUHCr6xNAUgc.qQj_Fo0Xr3ekPOCy_oQX0{height:30px;line-height:28px;padding:0 12px 2px}._1Hib1kNYIh4Y88GJR20ixL._3gdybrodQ9QKYnhyyOQ7nb ._3KHDMvFXbIlUHCr6xNAUgc,._3KHDMvFXbIlUHCr6xNAUgc._3gdybrodQ9QKYnhyyOQ7nb{height:24px;line-height:22px;padding:0 8px 1px;font-size:11px}._1Hib1kNYIh4Y88GJR20ixL._2dzenSWpCiE78p4mSgw5bb ._3KHDMvFXbIlUHCr6xNAUgc,._3KHDMvFXbIlUHCr6xNAUgc._2dzenSWpCiE78p4mSgw5bb{font-size:14px;height:46px;line-height:44px;padding:0 36px}input[type=reset],input[type=reset]:active,input[type=reset]:focus,input[type=reset]:hover{background:0 0;border:0;padding:0 2px 1px;width:auto;box-shadow:none}p .button{vertical-align:baseline}button::-moz-focus-inner,input[type=button]::-moz-focus-inner,input[type=reset]::-moz-focus-inner,input[type=submit]::-moz-focus-inner{border-width:1px 0;border-style:solid none;border-color:transparent;padding:0}
/*# sourceMappingURL=jetpack-onboarding.css.map*/